summaryrefslogtreecommitdiffstats
path: root/llvm/lib/Transforms/Scalar/IndVarSimplify.cpp
diff options
context:
space:
mode:
authorPhilip Reames <listmail@philipreames.com>2019-08-14 21:58:13 +0000
committerPhilip Reames <listmail@philipreames.com>2019-08-14 21:58:13 +0000
commit7b0515176b15715e554cf46f896eaf07da7b49f0 (patch)
tree17dad0518f7b308dd894d804c7f0f854b8d41429 /llvm/lib/Transforms/Scalar/IndVarSimplify.cpp
parent1bebc22bd94d44214bbd8a2dad10736c7c5e205b (diff)
downloadbcm5719-llvm-7b0515176b15715e554cf46f896eaf07da7b49f0.tar.gz
bcm5719-llvm-7b0515176b15715e554cf46f896eaf07da7b49f0.zip
[SCEV] Rename getMaxBackedgeTakenCount to getConstantMaxBackedgeTakenCount [NFC]
llvm-svn: 368930
Diffstat (limited to 'llvm/lib/Transforms/Scalar/IndVarSimplify.cpp')
-rw-r--r--llvm/lib/Transforms/Scalar/IndVarSimplify.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/llvm/lib/Transforms/Scalar/IndVarSimplify.cpp b/llvm/lib/Transforms/Scalar/IndVarSimplify.cpp
index 246ddfd28f6..bb524f7ad69 100644
--- a/llvm/lib/Transforms/Scalar/IndVarSimplify.cpp
+++ b/llvm/lib/Transforms/Scalar/IndVarSimplify.cpp
@@ -2647,11 +2647,11 @@ bool IndVarSimplify::optimizeLoopExits(Loop *L) {
// Form an expression for the maximum exit count possible for this loop. We
// merge the max and exact information to approximate a version of
// getMaxBackedgeTakenInfo which isn't restricted to just constants.
// TODO: factor this out as a version of getMaxBackedgeTakenCount which
// isn't guaranteed to return a constant.
SmallVector<const SCEV*, 4> ExitCounts;
- const SCEV *MaxConstEC = SE->getMaxBackedgeTakenCount(L);
+ const SCEV *MaxConstEC = SE->getConstantMaxBackedgeTakenCount(L);
if (!isa<SCEVCouldNotCompute>(MaxConstEC))
ExitCounts.push_back(MaxConstEC);
for (BasicBlock *ExitingBB : ExitingBlocks) {
@@ -2647,11 +2647,11 @@ bool IndVarSimplify::optimizeLoopExits(Loop *L) {
// Form an expression for the maximum exit count possible for this loop. We
// merge the max and exact information to approximate a version of
- // getMaxBackedgeTakenInfo which isn't restricted to just constants.
- // TODO: factor this out as a version of getMaxBackedgeTakenCount which
+ // getConstantMaxBackedgeTakenCount which isn't restricted to just constants.
+ // TODO: factor this out as a version of getConstantMaxBackedgeTakenCount which
// isn't guaranteed to return a constant.
SmallVector<const SCEV*, 4> ExitCounts;
OpenPOWER on IntegriCloud